@@ -16,6 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
+#define G_LOG_DOMAIN "sp-window"
+
 #include <errno.h>
 #include <glib/gi18n.h>
 #include <math.h>
@@ -403,6 +407,7 @@ sp_window_add_sources (SpWindow   *window,
   g_autoptr(SpSource) host_source = NULL;
   g_autoptr(SpSource) proc_source = NULL;
   g_autoptr(SpSource) perf_source = NULL;
+  g_autoptr(SpSource) memory_source = NULL;
 
   g_assert (SP_IS_WINDOW (window));
   g_assert (SP_IS_PROFILER (profiler));
@@ -415,6 +420,9 @@ sp_window_add_sources (SpWindow   *window,
 
   host_source = sp_hostinfo_source_new ();
   sp_profiler_add_source (profiler, host_source);
+
+  memory_source = sp_memory_source_new ();
+  sp_profiler_add_source (profiler, memory_source);
 }
 
 static void
@@ -855,6 +863,10 @@ sp_window_init (SpWindow *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
+#ifdef DEVELOPMENT_BUILD
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (self)), "development-version");
+#endif
+
   /*
    * Hookup widget signals.
    */
